===============================
py7zr -- a 7z library on python
===============================

.. toctree::
   :maxdepth: 3

   user_guide
   api
   contribution
   archive_format
   authors
   glossary
   changelog

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
